library(raster)
library(ggplot2)
library(sf)
library(viridis)


theme_map <- function(...) {
  theme_minimal() +
    theme(
      axis.line = element_blank(),
      axis.text.x = element_blank(),
      axis.text.y = element_blank(),
      axis.ticks = element_blank(),
      #axis.title.x = element_blank(),
      #axis.title.y = element_blank(),
      #panel.grid.minor = element_line(color = "white", size = 0.2),
      panel.grid.major = element_blank(),#element_line(color = "white", size = 0.2),
      panel.grid.minor = element_blank(),
      #plot.background = element_rect(fill = "#ebebe5", color = NA), 
      #panel.background = element_rect(fill = "#ebebe5", color = NA), 
      #legend.background = element_rect(fill = "#ebebe5", color = NA),
      #panel.border = element_blank(),
      ...
    )
}

shp <- st_read("countries.shp", quiet = T)
#shp <- st_simplify(shp, preserveTopology = F, dTolerance = 1000)
#top <- raster("relief50.tif")
e <- extent(-180.0001, 179.9999, -60, 90)
#topc <- crop(top, e)
#topc <- mask(topc, shp)


r <- raster("clipped_AM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

#--- convert to data.frame ---#
tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

#top_df  <- rasterToPoints(topc)
#top_df <- as.data.frame(top_df)

#ggplot() +
#  geom_sf(data = shp, colour = "lightgrey", size = 0.1)+
#  coord_sf(expand = FALSE)

p <- ggplot() +
  #geom_tile(data = top_df, aes(x = x, y = y, alpha = `relief50`)) +
  # use the "alpha hack"
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_AM`)) +
  # add the previously defined basic theme
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("a) AM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks = c(0.5, 0.75, 1),
                       limits = c(0.5, 1), oob = scales::squish,
                       labels = c("50%", "75%", "100%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("AM_new.tiff", device='tiff', dpi = 300)


r <- raster("clipped_ECM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

p <- ggplot() +
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_ECM`)) +
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("b) ECM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks=c(0, 0.1, 0.2), 
                       limits=c(0, 0.2),oob = scales::squish,
                       labels = c("0%", "10%", "20%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("ECM_new.tiff", device='tiff', dpi = 300)


r <- raster("clipped_ERM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

p <- ggplot() +
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_ERM`)) +
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("c) ERM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks=c(0, 0.04, 0.08), 
                       limits=c(0, 0.08),oob = scales::squish,
                       labels = c("0%", "4%", "8%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("ERM_new.tiff", device = 'tiff', dpi = 300)

r <- raster("clipped_ORM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

p <- ggplot() +
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_ORM`)) +
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("ORM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks=c(0, 0.02, 0.04), 
                       limits=c(0, 0.04),oob = scales::squish,
                       labels = c("0%", "2%", "4%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("ORM_new.tiff", device='tiff', dpi = 300)

r <- raster("clipped_NM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

p <- ggplot() +
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_NM`)) +
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("d) NM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks=c(0, 0.08, 0.16), 
                       limits=c(0, 0.16),oob = scales::squish,
                       labels = c("0%", "8%", "16%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("NM_new.tiff", device='tiff', dpi = 300)

r <- raster("clipped_FM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

p <- ggplot() +
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_FM`)) +
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("e) FM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks=c(0, 0.4, 0.8), 
                       limits=c(0, 0.8),oob = scales::squish,
                       labels = c("0%", "40%", "80%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("FM_new.tiff", device='tiff', dpi = 300)

r <- raster("clipped_OM.tif")
rc <- crop(r, e)
rc <- mask(rc, shp)

tmax_Jan_09_df  <- rasterToPoints(rc)
tmax_Jan_09_df <- as.data.frame(tmax_Jan_09_df)

p <- ggplot() +
  scale_alpha(name = "", range = c(0.02, 0.7), guide = "none")  +
  geom_sf(data = shp, fill = "#f0f0f0", colour = "lightsteelblue3", size = 0.01) + 
  geom_tile(data = tmax_Jan_09_df, aes(x = x, y = y, fill = `clipped_OM`)) +
  theme_map() +
  labs(x = NULL, 
       y = NULL) +
  ggtitle("f) OM")

p + 
  theme(legend.position = c(0.65, 0.07),
        legend.text = element_text(size = 9, face = "bold"),
        plot.title = element_text(hjust = 0.05, vjust = -15)) +
  scale_fill_viridis(option = "turbo",
                       breaks=c(0.1, 0.5, 0.9), 
                       limits=c(0.1, 0.9),oob = scales::squish,
                       labels = c("10%", "50%", "90%"),
                       name = "",
                       guide = guide_colorbar(
                         direction = "horizontal",
                         barheight = unit(2.5, units = "mm"),
                         barwidth = unit(50, units = "mm"),
                         draw.ulim = F)
  )
ggsave("OM_new.tiff", device='tiff', dpi = 300)








