#setwd("~/50km_map")
# load data
df <- read.csv("9_50km_46957grids.csv")
climate <- read.csv("25_climate.csv") #split from "9_50km_46957grids.csv"
soil <- read.csv("28_soil.csv") #split from "9_50km_46957grids.csv"


# get PCA
pca_climate <- prcomp(climate, scale = TRUE)
summ_c <- summary(pca_climate)
summ_c$importance[2,]

pca_soil <- prcomp(soil, scale = TRUE)
summ_c <- summary(pca_soil)
summ_c$importance[2,]


PC_climate_25 <- cbind(pca_climate$x[, 1:2], df[, 62:68])
PC_soil_28 <- cbind(pca_soil$x[, 1:2], df[, 62:68])
PC_climate_25[is.na(PC_climate_25)] <- 0
PC_soil_28[is.na(PC_soil_28)] <- 0

# set quantiles
PC1_soil_28_quantiles <- quantile(PC_soil_28$PC1, c(0.005, 0.995))
PC1_soil_28_subset <- PC_soil_28[PC_soil_28$PC1 > PC1_soil_28_quantiles[1] &
                                    PC_soil_28$PC1 < PC1_soil_28_quantiles[2], ]
PC2_soil_28_quantiles <- quantile(PC_soil_28$PC2, c(0.005, 0.995))
PC2_soil_28_subset <- PC_soil_28[PC_soil_28$PC2 > PC2_soil_28_quantiles[1] &
                                   PC_soil_28$PC2 < PC2_soil_28_quantiles[2], ]

PC1_climate_25_quantiles <- quantile(PC_climate_25$PC1, c(0.005, 0.995))
PC1_climate_25_subset <- PC_climate_25[PC_climate_25$PC1 > PC1_climate_25_quantiles[1] &
                                                PC_climate_25$PC1 < PC1_climate_25_quantiles[2], ]
PC2_climate_25_quantiles <- quantile(PC_climate_25$PC2, c(0.005, 0.995))
PC2_climate_25_subset <- PC_climate_25[PC_climate_25$PC2 > PC2_climate_25_quantiles[1] &
                                         PC_climate_25$PC2 < PC2_climate_25_quantiles[2], ]


library(ggplot2)
library(tidyr)
library(egg)



AMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = AM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = AM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0.25, 1)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim = PC1_soil_28_quantiles)

AMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = AM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = AM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0.25, 1)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

AMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = AM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = AM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0.25, 1)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold"),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank()) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

AMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = AM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = AM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0.25, 1)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_AM <- ggarrange(AMpC1_climate, AMpC2_climate, AMpC1_soil, AMpC2_soil, 
               nrow = 2, ncol = 2,
               labels = c("Climatic", "", "Edaphic", ""),
               label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "AM_PC2.tiff", device = 'tiff', g_AM )

ECMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = ECM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = ECM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim  = c(-8, 8))

ECMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = ECM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = ECM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

ECMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = ECM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = ECM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

ECMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = ECM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = ECM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_ECM <- ggarrange(ECMpC1_climate, ECMpC2_climate, ECMpC1_soil, ECMpC2_soil, 
                   nrow = 2, ncol = 2, 
                   labels = c("Climatic", "", "Edaphic", ""),
                   label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "ECM_PC2.tiff", device = 'tiff', g_ECM )

ERMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = ERM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = ERM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.4), breaks = c(0.1, 0.2, 0.3, 0.4)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim  = c(-8, 8))

ERMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = ERM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = ERM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.4), breaks = c(0.1, 0.2, 0.3, 0.4)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

ERMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = ERM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = ERM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.4), breaks = c(0.1, 0.2, 0.3, 0.4)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

ERMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = ERM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = ERM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.4), breaks = c(0.1, 0.2, 0.3, 0.4)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_ERM <- ggarrange(ERMpC1_climate, ERMpC2_climate, ERMpC1_soil, ERMpC2_soil, 
                   nrow = 2, ncol = 2, 
                   labels = c("Climatic", "", "Edaphic", ""),
                   label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "ERM_PC2.tiff", device = 'tiff', g_ERM )

ORMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = ORM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = ORM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.35)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim  = c(-8, 8))

ORMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = ORM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = ORM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.35)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

ORMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = ORM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = ORM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.35)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

ORMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = ORM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = ORM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.35)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_ORM <- ggarrange(ORMpC1_climate, ORMpC2_climate, ORMpC1_soil, ORMpC2_soil, 
                   nrow = 2, ncol = 2, 
                   labels = c("Climatic", "", "Edaphic", ""),
                   label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "ORM_PC2.tiff", device = 'tiff', g_ORM )

NMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = NM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = NM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim  = c(-8, 8))

NMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = NM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = NM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

NMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = NM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = NM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

NMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = NM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = NM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), limits = c(0, 0.5), breaks = c(0.1, 0.2, 0.3, 0.4, 0.5)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_NM <- ggarrange(NMpC1_climate, NMpC2_climate, NMpC1_soil, NMpC2_soil, 
                  nrow = 2, ncol = 2, 
                  labels = c("Climatic", "", "Edaphic", ""),
                  label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "NM_PC2.tiff", device = 'tiff', g_NM )

FMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = FM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = FM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim  = c(-8, 8))

FMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = FM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = FM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

FMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = FM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = FM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

FMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = FM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = FM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_FM <- ggarrange(FMpC1_climate, FMpC2_climate, FMpC1_soil, FMpC2_soil, 
                  nrow = 2, ncol = 2, 
                  labels = c("Climatic", "", "Edaphic", ""),
                  label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "FM_PC2.tiff", device = 'tiff', g_FM )

OMpC1_soil <- ggplot(data = PC_soil_28, aes(x = PC1)) +
  geom_point(aes(y = OM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_soil_28_subset, aes(x = PC1, y = OM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text = element_text(size = 14),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (28.4%)", y = "") +
  coord_cartesian(xlim  = c(-8, 8))

OMpC1_climate <- ggplot(data = PC_climate_25, aes(x = PC1)) +
  geom_point(aes(y = OM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC1_climate_25_subset, aes(x = PC1, y = OM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text.y = element_text(size = 14),
        axis.text.x = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(title ="",  x = "PC1 (46.1%)", y = "") +
  coord_cartesian(xlim = c(-8, 8))

OMpC2_soil <- ggplot(data = PC_soil_28, aes(x = PC2)) +
  geom_point(aes(y = OM), color = "#CCFFCC", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_soil_28_subset, aes(x = PC2, y = OM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text.x = element_text(size = 14),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (15.4%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

OMpC2_climate <- ggplot(data = PC_climate_25, aes(x = PC2)) +
  geom_point(aes(y = OM), color="#CCFFFF", alpha = 0.1, size = 1.2) +
  geom_smooth(data = PC2_climate_25_subset, aes(x = PC2, y = OM), 
              method = 'loess', se = F, color = "black", alpha = 0.9) +
  scale_y_continuous(labels = function(x) paste0(x*100, "%"), breaks = c(0.25, 0.5, 0.75, 1)) +
  theme_minimal() + 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        axis.title.x = element_text(size = 14, face = "bold")) +
  labs(x = "PC2 (25.1%)", y = "") +
  coord_cartesian(xlim = c(-9, 6))

g_OM <- ggarrange(OMpC1_climate, OMpC2_climate, OMpC1_soil, OMpC2_soil, 
                  nrow = 2, ncol = 2, 
                  labels = c("Climatic", "", "Edaphic", ""),
                  label.args = list(gp = grid::gpar(font = 4, cex = 1.2)))
ggsave(file = "OM_PC2.tiff", device = 'tiff', g_OM )



